@@ -1031,7 +1031,7 @@ meta_window_actor_has_shadow (MetaWindowActor *self)
     return TRUE;
 #endif
 
-  return TRUE;
+  return FALSE;
 }
 
 /**
@@ -1289,7 +1289,11 @@ meta_window_actor_queue_frame_drawn (MetaWindowActor *self,
 
   priv->needs_frame_drawn = TRUE;
 
+#ifdef HAVE_XSYNC
   frame->sync_request_serial = priv->window->sync_request_serial;
+#else
+  frame->sync_request_serial = 0;
+#endif
 
   priv->frames = g_list_prepend (priv->frames, frame);
 
@@ -1927,7 +1931,7 @@ ensure_tooltip_visible (MetaWindow *window)
     }
   else if (win_rect.x + win_rect.width > work_area.x + work_area.width)
     {
-      new_y = (work_area.x + work_area.width - win_rect.width);
+      new_x = (work_area.x + work_area.width - win_rect.width);
     }
 
   if (new_x != win_rect.x || new_y != win_rect.y)
