@@ -50,6 +50,7 @@
 #include <X11/Xatom.h>
 #include <unistd.h>
 #include <string.h>
+#include "util-private.h"
 #ifndef HOST_NAME_MAX
 /* Solaris headers apparently don't define this so do so manually; #326745 */
 #define HOST_NAME_MAX 255
@@ -444,7 +445,7 @@ reload_net_wm_pid (MetaWindow    *window,
       gulong cardinal = (int) value->v.cardinal;
 
       if (cardinal <= 0)
-        meta_warning (_("Application set a bogus _NET_WM_PID %lu\n"),
+        meta_warning ("Application set a bogus _NET_WM_PID %lu\n",
                       cardinal);
       else
         {
@@ -1140,9 +1141,8 @@ reload_update_counter (MetaWindow    *window,
   if (value->type != META_PROP_VALUE_INVALID)
     {
       meta_window_destroy_sync_request_alarm (window);
-      window->sync_request_counter = None;
-
 #ifdef HAVE_XSYNC
+      window->sync_request_counter = None;
       if (value->v.xcounter_list.n_counters == 0)
         {
           meta_warning ("_NET_WM_SYNC_REQUEST_COUNTER is empty\n");
@@ -1831,8 +1831,8 @@ reload_transient_for (MetaWindow    *window,
             }
           else
             {
-              meta_warning (_("Invalid WM_TRANSIENT_FOR window 0x%lx specified "
-                              "for %s.\n"),
+              meta_warning ("Invalid WM_TRANSIENT_FOR window 0x%lx specified "
+                              "for %s.\n",
                             transient_for, window->desc);
               transient_for = None;
             }
@@ -1843,8 +1843,8 @@ reload_transient_for (MetaWindow    *window,
         {
           if (parent == window)
             {
-              meta_warning (_("WM_TRANSIENT_FOR window 0x%lx for %s "
-                              "would create loop.\n"),
+              meta_warning ("WM_TRANSIENT_FOR window 0x%lx for %s "
+                              "would create loop.\n",
                             transient_for, window->desc);
               transient_for = None;
               break;
