@@ -343,8 +343,6 @@ struct _MetaAlphaGradientSpec
 
 struct _MetaDrawInfo
 {
-  GdkPixbuf   *mini_icon;
-  GdkPixbuf   *icon;
   PangoLayout *title_layout;
   int title_layout_width;
   int title_layout_height;
@@ -820,10 +818,18 @@ struct _MetaFrameStyleSet
   MetaFrameStyle *maximized_styles[META_FRAME_FOCUS_LAST];
   MetaFrameStyle *tiled_left_styles[META_FRAME_FOCUS_LAST];
   MetaFrameStyle *tiled_right_styles[META_FRAME_FOCUS_LAST];
+  MetaFrameStyle *tiled_ulc_styles[META_FRAME_FOCUS_LAST];
+  MetaFrameStyle *tiled_llc_styles[META_FRAME_FOCUS_LAST];
+  MetaFrameStyle *tiled_urc_styles[META_FRAME_FOCUS_LAST];
+  MetaFrameStyle *tiled_lrc_styles[META_FRAME_FOCUS_LAST];
   MetaFrameStyle *shaded_styles[META_FRAME_RESIZE_LAST][META_FRAME_FOCUS_LAST];
   MetaFrameStyle *maximized_and_shaded_styles[META_FRAME_FOCUS_LAST];
   MetaFrameStyle *tiled_left_and_shaded_styles[META_FRAME_FOCUS_LAST];
   MetaFrameStyle *tiled_right_and_shaded_styles[META_FRAME_FOCUS_LAST];
+  MetaFrameStyle *tiled_ulc_and_shaded_styles[META_FRAME_FOCUS_LAST];
+  MetaFrameStyle *tiled_llc_and_shaded_styles[META_FRAME_FOCUS_LAST];
+  MetaFrameStyle *tiled_urc_and_shaded_styles[META_FRAME_FOCUS_LAST];
+  MetaFrameStyle *tiled_lrc_and_shaded_styles[META_FRAME_FOCUS_LAST];
 };
 
 /**
@@ -859,6 +865,8 @@ struct _MetaTheme
    */
   guint format_version;
 
+  guint scale;
+
   /** Symbol table of integer constants. */
   GHashTable *integer_constants;
   /** Symbol table of float constants. */
@@ -1028,9 +1036,7 @@ void meta_frame_style_draw (MetaFrameStyle          *style,
                             int                      client_height,
                             PangoLayout             *title_layout,
                             int                      text_height,
-                            MetaButtonState          button_states[META_BUTTON_TYPE_LAST],
-                            GdkPixbuf               *mini_icon,
-                            GdkPixbuf               *icon);
+                            MetaButtonState          button_states[META_BUTTON_TYPE_LAST]);
 
 
 void meta_frame_style_draw_with_style (MetaFrameStyle          *style,
@@ -1042,9 +1048,7 @@ void meta_frame_style_draw_with_style (MetaFrameStyle          *style,
                                        int                      client_height,
                                        PangoLayout             *title_layout,
                                        int                      text_height,
-                                       MetaButtonState          button_states[META_BUTTON_TYPE_LAST],
-                                       GdkPixbuf               *mini_icon,
-                                       GdkPixbuf               *icon);
+                                       MetaButtonState          button_states[META_BUTTON_TYPE_LAST]);
 
 
 gboolean       meta_frame_style_validate (MetaFrameStyle    *style,
@@ -1081,9 +1085,7 @@ void meta_theme_draw_frame (MetaTheme              *theme,
                             PangoLayout            *title_layout,
                             int                     text_height,
                             const MetaButtonLayout *button_layout,
-                            MetaButtonState         button_states[META_BUTTON_TYPE_LAST],
-                            GdkPixbuf              *mini_icon,
-                            GdkPixbuf              *icon);
+                            MetaButtonState         button_states[META_BUTTON_TYPE_LAST]);
 
 void meta_theme_draw_frame_with_style (MetaTheme              *theme,
                                        GtkStyleContext        *style_gtk,
@@ -1096,9 +1098,7 @@ void meta_theme_draw_frame_with_style (MetaTheme              *theme,
                                        PangoLayout            *title_layout,
                                        int                     text_height,
                                        const MetaButtonLayout *button_layout,
-                                       MetaButtonState         button_states[META_BUTTON_TYPE_LAST],
-                                       GdkPixbuf              *mini_icon,
-                                       GdkPixbuf              *icon);
+                                       MetaButtonState         button_states[META_BUTTON_TYPE_LAST]);
 
 void meta_theme_get_frame_borders (MetaTheme         *theme,
                                    MetaFrameType      type,
